Dependencies:
Import pandas, time and datetime

Import function using the command below:
from stockdata.pdstock import stockdata

Function:
Call stockdata('STOCK TICKER', NUMBER OF YEARS OF DATA)
e.g stockdata('AMZN',5)